import axios from "axios";
import notification from "ant-design-vue/es/notification";
import store from "@/index/store";
import { accessTokenError } from "@/index/utils/errorModal";
import Vue from "vue";
import JSONBigint from "json-bigint";

const axiosInstance = axios.create({
  baseURL: process.env.VUE_APP_API_BASE_URL,
  // baseURL: 'http://134.175.125.24',
  timeout: 30000,
  transformResponse: [
    function(data) {
      // 对大数字进行特殊处理
      try {
        return JSONBigint.parse(data);
      } catch (err) {
        return data;
      }
    },
  ],
});
const errorHandler = (err) => {
  if (err.message.errcode) {
    // 后端返回的错误码
    notification.error({
      key: "requestError",
      message: "请求错误",
      description: err.message.errmsg,
    });
    return err.message
  } else {
    // http 返回的错误码
    let errMsg = "";
    if (err.code === "ECONNABORTED") {
      errMsg = "网络请求超时";
    } else {
      if (err && err.response) {
        let status = err.response.status;
        switch (status) {
          case 400:
            errMsg = "参数错误";
            break;
          case 401:
            Vue.ls.clear()
            if(!Vue.prototype.$closeModalFun){
            // if(false){
              Vue.prototype.$closeModalFun = accessTokenError('系统已超时自动退出，请点击左边导航栏应用“资源管理”重新登录。')
            }
            break;
          case 403:
            // Vue.ls.clear()
            if(!Vue.prototype.$closeModalFun){
              Vue.prototype.$closeModalFun = accessTokenError('登录信息已过期，请点击左边导航栏应用“资源管理”重新登录。');
            }
            break;
          case 404:
            errMsg = "没有找到相关资源";
            break;
          case 405:
            errMsg = "请求方法不允许";
            break;
          case 500:
            errMsg = "服务器异常";
            break;
          default:
            errMsg = "连接服务器出错" + status;
        }
      } else {
        errMsg = "连接服务器失败";
      }
    }
    store.commit("reduceLoadingCount", { hasError: true });
    errMsg && notification.error({
      key: "requestError",
      message: "请求错误",
      description: errMsg,
    });
    return err
  }
};

axiosInstance.interceptors.request.use(
  (config) => {
    if (config.method === 'get') {
      config.params = config.data;
    }
    // 控制 loading 显示
    if (config.data && config.data._loading === false) {
      const { _loading, ...data } = config.data;
      config.headers._loading = _loading !== false;
      config.data = data;
      if (data.formData) {
        // form data 数据需要特殊处理
        config.data = data.formData;
      }
    }
    if (config.headers._loading !== false) {
      config.headers._loading = true;
      store.commit("addLoadingCount");
    }

    // 头部增加 token
    if (store.state.user.token) {
      config.headers.Authorization = "Bearer " + store.state.user.token;
    }

    return config;
  },
  (err) => {
    return Promise.reject(err);
  }
);

axiosInstance.interceptors.response.use((response) => {
  let { _loading } = response.config.headers;
  if (_loading) {
    store.commit("reduceLoadingCount", { hasError: false });
  }
  if (!response.data) {
    return response;
  }
  if (response.data.errcode) {
    // 如果 errcode 有值并且不为0的时候抛出错误
    return errorHandler({ message: response.data });
  }
  // return { result: response.data };
  return response.data
}, errorHandler);

// export default axiosInstance;

const request = (method, url, data = {}) => {
  return axiosInstance.request({
      method,
      url,
      data
  }).then(data => data
  ).catch(err => ({
      err
  }))
}
export default request