/** 系统设置相关api */
import request from "./request"
const baseUrl = '/czrm'

/** 1.1 获取所有团队列表 */
export function getTeamList(params={}) {
    return request('get', baseUrl + '/api/setting/org/team/list', params)
}
/** 1.2 新增/编辑 团队 */
export function addTeam(params) {
  return request('post', baseUrl + '/api/setting/org/team/save', params)
}
/** 1.3 更新团队状态 */
export function updataTeam(params) {
  return request('post', baseUrl + '/api/setting/org/team/updateStatus', params)
}


/** 2.1 获取所有业务组列表 */
export function getGroupList(params) {
  return request('get', baseUrl + '/api/setting/org/group/list', params)
}
/** 2.2 新增/编辑 业务组 */
export function addGroup(params) {
  return request('post', baseUrl + '/api/setting/org/group/save', params)
}
/** 2.3 更新业务组状态 */
export function updataGroup(params) {
  return request('post', baseUrl + '/api/setting/org/group/updateStatus', params)
}

/** 3.1 获取所有技改项目列表 */
export function getProjectList() {
  return request('get', baseUrl + '/api/setting/org/project/list')
}
/** 3.2 新增/编辑 技改项目 */
export function addProject(params) {
  return request('post', baseUrl + '/api/setting/org/project/save', params)
}
/** 3.3 更新技改项目状态 */
export function updataProject(params) {
  return request('post', baseUrl + '/api/setting/org/project/updateStatus', params)
}

/** 4.1 获取Tapd团队成员 */
export function getMemberList() {
  return request('get', baseUrl + '/api/setting/org/team/member/list')
}
/** 4.2 获取Tapd项目 */
export function getTapdProject() {
  return request('get', baseUrl+ '/api/setting/syn/getProviderProject')
}

/** 5.1 获取所有项目映射规则 */
export function getProjectAllRules() {
  return request('get', baseUrl+ '/api/setting/syn/getAllRules')
}
/** 5.2 删除项目映射规则 */
export function delProjectRule(params) {
  return request('post', baseUrl+ '/api/setting/syn/deleteRule', params)
}
/** 5.3 新增项目映射规则 */
export function addProjectRules(params) {
  return request('post', baseUrl+ '/api/setting/syn/addRules', params)
}
/** 5.4 修改项目映射规则 */
export function updataProjectRule(params) {
  return request('post', baseUrl+ '/api/setting/syn/updateRule', params)
}


/** 需求映射规则 */
export function getWorkflowStateList(params){
  return request('get', baseUrl + `/api/setting/mapping/status/${params.system}/${params.projectId}/${params.storyTypeId}`, params)
}

export function getCustomStory(params){
  return request('get', baseUrl + `/api/setting/mapping/story/fields/${params.projectId}`, params)
}

export function getMappingRuleList(params){
  return request('get', baseUrl + `/api/setting/mapping/list`, params)
}

export function getMappingRuleListShowPages (params){
  return request('get', baseUrl + `/api/setting/mapping/list/${params.pageSize}/${params.pageNum}`, params)
}

export function removeMappingRule(params){
  return request('get', baseUrl + `/api/setting/mapping/remove/${params.outerId}`, params)
}

export function saveDraft(params){
  return request('post', baseUrl + `/api/setting/mapping/form/draft`, params)
}

export function updateMappingForm(params){
  return request('post', baseUrl + `/api/setting/mapping/form/update`, params)
}

export function saveMappingForm(params){
  return request('post', baseUrl + `/api/setting/mapping/form/save`, params)
}

export function getMappingForm(params){
  return request('get', baseUrl + `/api/setting/mapping/info/${params.outerId}`, params)
}

export function getInitMappingForm(params){
  return request('get', baseUrl + '/api/setting/mapping/form', params)
}

// export function getProjectNameList(params){
//   return request('get', baseUrl + `/api/setting/mapping/projects`, params)
// }

export function getStoryTypes(params){
  return request('get', baseUrl + `/api/setting/mapping/storytypes/${params.projectId}`, params)
}

export function getDraft(params){
  return request('post', baseUrl + `/api/setting/mapping/form/${params.projectId}`, params)
}


/**  权限管理 相关 白名单模式 */
/**
 * 7.1 登录白名单列表/需求资源确认记录白名单列表
 * @param {Object} params {type: 0 ,page:1, pageSize:10, nick: ''}
 * @param {Number} params.type -  0为登录权限, 1是查看需求确认记录
 * @param {Number} params.page - 页码
 * @param {Number} params.pageSize - 每页条数
 * @param {Number} params.nick - 昵称(支持模糊搜索)
 */
export function getWhiteList(params){
  return request('get', baseUrl + '/api/setting/whitelist/list', params)
}

/**
 * 7.2 添加进白名单
 * @param {Object} option
 * @param {Object} option.type -  0为登录权限, 1是查看需求确认记录
 * @param {Object} option.nickList -  ['张三', '李四']}, 
 * @returns 
 */
export function addWhiteList({type,nickList}){
  return request('post', baseUrl + `/api/setting/whitelist/save?type=${type}`, nickList)
}

/**
 * 7.3 从白名单中删除
 * @param {Object} option
 * @param {Number} option.type - 0为登录权限, 1是查看需求确认记录
 * @param {Number} option.id - list中的id
 * @returns
 */
export function delWhiteList({type, id}){
  return request('post', baseUrl + `/api/setting/whitelist/delete?type=${type}&id=${id}`, )
}

/**  权限管理 相关 tapd角色组模式*/
/** 
 * 8.1 权限列表: 包括每个权限对应的id
 * @returns {List} [{id, code, name}] 发起审批id: 3
 */
export function getPermisionList(){
  return request('post', baseUrl + '/oauth/role/resources')
}

/** 
 * 8.2 已授权列表, 这个接口暂时只能查发起审批权限
 * @param {Object} option
 * @param {Number} option.pageNum - 页码
 * @param {Number} option.pageSize - 每页条数
 * @param {Object} option.data -  {resourceId: 2,roleGroupName: ''} 
 * resourceId: 为权限类型对应的id, 发起审批: 3
 * roleGroupName: 可选参数, 模糊查询项目名称
 */
export function getAuthorizedList({pageNum, pageSize, ...data}){
  return request('post', baseUrl + `/oauth/role/resource/group/${pageSize}/${pageNum}`, data)
}

/** 
 * 8.3 添加授权/修改授权
 * @param {Object} option
 * @param {Number} option.id - 权限类型对应的id, 发起审批: 3
 * @param {Array} option.params - [{"rgId":721, "roleIds":[550,558]},{"rgId":720, "roleIds":[]}]
 * @param {Number=} option.asyncUser - 1是获取tapd角色组下最新的用户, 其余或者不传不更新 
 * 一般第一次添加的时候传, 保存修改的时候不传
 */
export function addAuthorization({id, params, asyncUser=''}){
  return request('post', baseUrl + `/oauth/role/resource/${id}/${asyncUser}`, params)
}

/**
 * 8.3.1 获取角色组列表, 其实就是对应tapd的项目 
 * @returns choose字段: 0: 未设置过的项目；1: 已经设置过的项目
 */
export function getRoleGroupList(params){
  return request('get', baseUrl + `/oauth/role/group/choose/list/${params}`)
}

/** 
 * 8.3.2 获取角色组下的角色, 其实就是对应tapd的项目下的用户组
 * @param {Number} params : 角色组对应的id
 */
export function getRoleList(params){
  return request('get', baseUrl + `/oauth/role/list/${params}`)
}

/**
 *  8.4 移除授权
 * @param {Object} params : {"rgId":711,"resourceId":3}
 */
export function delAuthorization(params){
  return request('post', baseUrl + '/oauth/role/resource/delete', params)
}

/**
 * 8.5 刷新Tapd角色组下最新用户
 * @param {Number} type - 3是发起审批权限
 * @param {Object} params - 角色组id,其实就是项目id, {rgId: 711}
 * @returns
 */
export function syncRoleGroupUsers({type, params}){
  return request('post', baseUrl + `/oauth/role/refresh/${type}`, params)
}

