import Menu from "ant-design-vue/es/menu";
import Icon from "ant-design-vue/es/icon";
import { mapState } from "vuex";

const { Item, SubMenu } = Menu;

export default {
  name: "SideMenu",
  props: {
    collapsed: {
      type: Boolean,
      required: false,
      default: false,
    },
  },
  data() {
    return {
      openKeys: [],
      selectedKeys: [],
      cachedOpenKeys: [],
    };
  },
  mounted() {
    this.updateMenu();
  },
  computed: {
    rootSubmenuKeys() {
      return this.routesResource.map((item) => item.path);
    },
    ...mapState({
      routesResource: (state) => state.user.routesResource,
    }),
  },
  watch: {
    $route: function() {
      this.updateMenu();
    },
    collapsed: function(newValue) {
      this.openKeys = newValue ? [] : this.cachedOpenKeys;
    },
  },
  methods: {
    onOpenChange(openKeys) {
      const latestOpenKey = openKeys.find((key) => this.openKeys.indexOf(key) === -1);
      if (this.rootSubmenuKeys.indexOf(latestOpenKey) === -1) {
        this.openKeys = openKeys;
      } else {
        this.openKeys = latestOpenKey ? [latestOpenKey] : [];
      }
    },
    updateMenu() {
      this.cachedOpenKeys = this.$route.matched.filter((element) => element.meta?.type === "subMenu").map((item) => item.path);
      this.selectedKeys = [this.$route.matched.find((element) => element.meta?.type === "menuItem")?.path];
      this.openKeys = this.collapsed ? [] : this.cachedOpenKeys;
      // setTimeout(() => {
      //   document
      //     .querySelector(".side-menu .ant-menu-item-selected")
      //     ?.closest(".side-menu>[role='menuitem']")
      //     .scrollIntoView();
      // }, 1000);
    },

    // render
    renderItem(menu) {
      if (menu.meta?.type === "subMenu") {
        return this.renderSubMenu(menu);
      } else if (menu.meta?.type === "menuItem") {
        return this.renderMenuItem(menu);
      } else {
        return null;
      }
    },
    renderMenuItem(menu) {
      return (
        <Item key={menu.path} style={{ textAlign: "left" }}>
          {
            menu.meta.href
            ?
            <a href={menu.meta.href} target="_blank">{menu.meta.title}</a>
            :
            <RouterLink to={{ path: menu.path }}>
              {this.renderIcon(menu.meta.icon)}
              <span>{menu.meta.title}</span>
            </RouterLink>
          }
        </Item>
      );
    },
    renderSubMenu(menu) {
      return (
        <SubMenu key={menu.path} style={{ textAlign: "left" }}>
          <span slot="title">
            {this.renderIcon(menu.meta.icon)}
            <span>{menu.meta.title}</span>
          </span>
          {menu.children.map((item) => this.renderItem(item))}
        </SubMenu>
      );
    },
    renderIcon(icon) {
      if (!icon) {
        return null;
      }
      return <Icon type={icon} />;
    },
  },

  render() {
    const menuTree = this.routesResource.map((item) => {
      return this.renderItem(item);
    });
    return (
      <Menu theme="dark" mode="inline" vModel={this.selectedKeys} openKeys={this.openKeys} on={{ openChange: this.onOpenChange }}>
        {menuTree}
      </Menu>
    );
  },
};
