import Vue from "vue";
import VueRouter from "vue-router";
import store from "@/index/store";
import { generateIndexRouter } from "./generateIndexRouter";
import systemSettings from './systemSettings'
// import { accessTokenError } from "@/index/utils/errorModal";

// hack router push callback
const originalPush = VueRouter.prototype.push;
VueRouter.prototype.push = function push(location, onResolve, onReject) {
  if (onResolve || onReject) return originalPush.call(this, location, onResolve, onReject);
  return originalPush.call(this, location).catch((err) => err);
};

Vue.use(VueRouter);

const routes = [
  {
    path: "/404",
    component: () => import(/* webpackChunkName: "404" */ "@/index/views/404"),
  },
  {
    path: "/loginFailed",
    component: () => import( "@/index/views/LoginFailed"),
  },
  // todo 管理员才添加系统设置路由
  // systemSettings
];

const router = new VueRouter({
  routes,
  scrollBehavior: () => ({ y: 0 }), // 管理滚动行为 如果出现滚动 切换就让页面回到顶部
});

let dynamicRoutes = [];

router.beforeEach(async(to, from, next)=>{
  // 1. 从tapd进来, 重定向路由参数带token
  // if(to.query.token){
  //   // 1.1 先删除本地存储
  //   Vue.ls.remove('token')
  //   // 1.2 设置token
  //   const tmp_token = to.query.token
  //   let formData = new FormData()
  //   formData.append("tmp_token", tmp_token)
  //   await store.dispatch('user/getToken', formData)
  //   if(store.state.user.token){
  //      // 1.2.1 能拿到正式token,保存token
  //     Vue.ls.set('token',store.state.user.token)
  //     // 跳转,去掉路由参数
  //     next({ path: to.path })
  //   }else{
  //     // 1.2.2 拿不到token
  //     // 1.2.2.1 判断是不是因为没有添加进白名单
  //     if(store.state.user.loginFailed){
  //       next({path: '/loginFailed'})
  //     }else{
  //       // 1.2.2.2 判断是否已弹提示
  //       if(!Vue.prototype.$closeModalFun){
  //         Vue.prototype.$closeModalFun = accessTokenError('获取token失败，请点击左边导航栏应用“资源管理”重试。')
  //       }
  //       next(false)
  //     }
  //   }
  // }else{
  // 2. 不是从tapd进来
    // 2.1 检查token
    // if(!store.state.user.token && !store.state.user.loginFailed){
    //   const token = Vue.ls.get('token')
    //   if(token){
    //     store.commit('user/changeToken', token)
    //   }else {
    //     if(!Vue.prototype.$closeModalFun){
    //       Vue.prototype.$closeModalFun = accessTokenError('获取token失败，请点击左边导航栏应用“资源管理”重试。')
    //     }
    //     // 拿不到token, 弹窗并停止
    //     next(false)
    //   }
    // }
    store.commit('user/changeToken', '123456')
    // 2.2 没有路由, 生成路由
    if ( store.state.user.token && dynamicRoutes.length === 0) {
      // 获取用户信息
      await store.dispatch('user/getUserInfo')
      store
        .dispatch("user/getRoutesResource")
        .then((routesResource) => {
          dynamicRoutes = generateIndexRouter(routesResource)
          router.addRoutes(dynamicRoutes)
          // 是管理员, 添加设置页面路由
          if(store.state.user.isAdmin){
            router.addRoutes([systemSettings]);
          }
        })
        .catch((err) => {
          Vue.prototype.$error("请求用户资源失败");
          console.log(err)
          next(false)
        })
    }
    // 2.4 已有路由
    next()
  // }


  // if(!store.state.token){
  // // if(false){
  //   const CURRENT_USER = localStorage.getItem('uid') || to.query["CURRENT-USER"];
  //   // debugger
  //   store.commit('saveUid', CURRENT_USER);
  //   localStorage.setItem('uid', CURRENT_USER);

  //   const token = localStorage.getItem('token');
  //   if(token){
  //     store.commit('changeToken', token);
  //     localStorage.removeItem('token');
  //     next({ path: to.path });
  //   }else{
  //     const tmp_token = to.query.token;
  //     if (tmp_token) {
  //         let formData = new FormData();
  //         formData.append("tmp_token", tmp_token);
  //         await store.dispatch('getToken', formData);
  //         if(store.state.token){
  //           // localStorage.setItem('token',store.state.token);
  //           next({ path: to.path });
  //         }else{
  //           if(!Vue.prototype.$closeModalFun){
  //             Vue.prototype.$closeModalFun = accessTokenError('获取token失败，请点击左边导航栏应用“资源管理”重试。');
  //           }
  //           next(false);
  //         }
  //     }else{
  //         if(!Vue.prototype.$closeModalFun){
  //           Vue.prototype.$closeModalFun = accessTokenError('获取临时token失败，请点击左边导航栏应用“资源管理”重试。');
  //         }
  //         next(false);
  //     }
  //   }
  // }else{
  //   if (dynamicRoutes.length === 0) {
  //     store
  //       .dispatch("user/getRoutesResource")
  //       .then((routesResource) => {
  //         dynamicRoutes = generateIndexRouter(routesResource);
  //         router.addRoutes(dynamicRoutes);
  //         if(store.state.isAdmin){
  //           router.addRoutes([systemSettings]);
  //         }
  //         next({ path: to.path, query: to.query });
  //       })
  //       .catch((err) => {
  //         Vue.prototype.$error("请求用户资源失败");
  //         console.log(err);
  //         next(false);
  //       });
  //   } else {
  //     next();
  //   }
  // }
})

export default router;
