export default {
  path: '/systemSettings',
  name: 'settings',
  component: () => import('@/index/views/systemSettings'),
  redirect: '/systemSettings/organizationManagement',
  children: [
    // 1. 组织管理
    {
      path: '/systemSettings/organizationManagement',
      name: 'settings-organization',
      component: () => import('@/index/components/layouts/BlankLayout'),
      redirect: '/systemSettings/team',
      meta: {
        icon: "appstore",
        title: "组织管理",
        type: "subMenu",
      }, 
      children: [
        // 1.1 团队设置
        {
          path: '/systemSettings/team',
          component: () => import('@/index/components/layouts/BlankLayout'),
          meta: {
            title: "团队设置",
            type: "menuItem",
          }, 
          children: [
            // 1.1.1 团队列表
            {
              path: '',
              name: 'settings-organization-teamList',
              component: () => import('@/index/views/systemSettings/organizationManagement/team/List'),
              meta: {
                isHiddenInBreadcrumbs: true,
              }
            },
            // 1.1.2 创建团队
            {
              path: '/systemSettings/team/Create',
              name: 'settings-organization-teamCreate',
              component: () => import('@/index/views/systemSettings/organizationManagement/team/Create'),
              meta: {
                title: "创建团队",
              }, 
            },
          ]
        },
        // 1.2 业务组设置
        {
          path: '/systemSettings/businessGroup',
          component: () => import('@/index/components/layouts/BlankLayout'),
          meta: {
            title: "业务组设置",
            type: "menuItem",
          }, 
          children: [
            // 1.2.1 业务组列表
            {
              path: '',
              name: 'settings-organization-businessGroupList',
              component: () => import('@/index/views/systemSettings/organizationManagement/businessGroup/List'),
              meta: {
                isHiddenInBreadcrumbs: true,
              }
            },
            // 1.2.2 创建业务工作组
            {
              path: '/systemSettings/businessGroup/Create',
              name: 'settings-organization-businessGroupCreate',
              component: () => import('@/index/views/systemSettings/organizationManagement/businessGroup/Create'),
              meta: {
                title: "创建业务工作组",
              }, 
            },
          ]
        },
        // 1.3 技改项目设置
        {
          path: '/systemSettings/renovationProject',
          component: () => import('@/index/components/layouts/BlankLayout'),
          meta: {
            title: "技改项目设置",
            type: "menuItem",
          }, 
          children: [
            // 1.3.1 技改项目列表
            {
              path: '',
              name: 'settings-organization-renovationProjectList',
              component: () => import('@/index/views/systemSettings/organizationManagement/renovationProject/List'),
              meta: {
                isHiddenInBreadcrumbs: true,
              }
            },
            // 1.3.2 新增技改项目
            {
              path: '/systemSettings/renovationProject/Create',
              name: 'settings-organization-renovationProjectCreate',
              component: () => import('@/index/views/systemSettings/organizationManagement/renovationProject/Create'),
              meta: {
                title: "新增技改项目",
              }, 
            },
          ]
        },
      ]
    },
    // 2. 映射规则设置
    {
      path: '/systemSettings/rule',
      name: 'settings-rule',
      component: () => import('@/index/components/layouts/BlankLayout'),
      redirect: '/systemSettings/team',
      meta: {
        icon: "appstore",
        title: "映射规则管理",
        type: "subMenu",
      }, 
      children: [
        // 2.1 项目映射
        {
          path: '/systemSettings/projectRules',
          component: () => import('@/index/components/layouts/BlankLayout'),
          meta: {
            title: "项目映射设置",
            type: "menuItem",
          }, 
          children: [
            // 2.1.1 列表
            {
              path: '',
              name: 'settings-rule-projectRulesList',
              component: () => import('@/index/views/systemSettings/rule/projectRules/List'),
              meta: {
                isHiddenInBreadcrumbs: true,
              }
            },
            // 2.1.2 新增
            {
              path: '/systemSettings/projectRules/Create',
              name: 'settings-rule-projectRulesCreate',
              component: () => import('@/index/views/systemSettings/rule/projectRules/Create'),
              meta: {
                title: "新增项目同步映射",
              }, 
            }
          ]
        },
        // 2.2 需求映射规则
        {
          path: '/systemSettings/demandMapping',
          name: 'settings-rule-demandMapping',
          component: () => import('@/index/views/systemSettings/rule/demandMapping/List'),
          meta: {
            title: "需求映射设置",
            type: "menuItem",
          }, 
        },
        {
          path: '/systemSettings/flowable',
          meta: {
            title: "审批引擎映射设置",
            type: "menuItem",
            href: "https://tapd.csair.com/flowable/",
          }, 
        }
      ]
    },
    // 3. 权限管理
    {
      path: '/systemSettings/permission',
      name: 'settings-permission',
      component: () => import('@/index/components/layouts/BlankLayout'),
      redirect: '/systemSettings/demandConfirmRecordView',
      meta: {
        icon: "appstore",
        title: "权限管理",
        type: "subMenu",
      }, 
      children: [
        // 3.0 登录白名单(管理员不需要添加进白名单也能直接进入系统)
        {
          path: '/systemSettings/loginWhiteList',
          component: () => import('@/index/views/systemSettings/permission/loginWhiteList'),
          meta: {
            title: "登录白名单",
            type: "menuItem"
          }
        },
        // 3.1 查看需求资源确认记录
        {
          path: '/systemSettings/demandConfirmRecordView',
          name: 'settings-permission-demandConfirmRecordView',
          component: () => import('@/index/views/systemSettings/permission/demandConfirmRecordView'),
          meta: {
            title: "需求资源确认记录",
            type: "menuItem",
          }, 
        },
        // 3.2 发起任务单审批
        {
          path: '/systemSettings/initiateApproval',
          component: () => import('@/index/components/layouts/BlankLayout'),
          redirect: '/systemSettings/demandConfirmRecordView',
          meta: {
            title: "发起审批",
            type: "menuItem",
          }, 
          children: [
            // 3.2.1 列表
            {
              path: '',
              name: 'settings-permission-initiateApproval-List',
              component: () => import('@/index/views/systemSettings/permission/initiateApproval/List'),
              meta: {
                isHiddenInBreadcrumbs: true,
              }
            },
            // 3.2.2 新增
            {
              path: '/systemSettings/initiateApproval/Create',
              name: 'settings-permission-initiateApproval-Create',
              component: () => import('@/index/views/systemSettings/permission/initiateApproval/Create'),
              meta: {
                title: "新增权限",
              }, 
            }
          ]
        },
      ]
    }
  ]
}