import {
  getProjectList,
  getTeamList,
  getGroupList,
  getMemberList,
  getTapdProject,
  getProjectAllRules,
  getPermisionList,
  getRoleGroupList,
} from '@/index/api'
import { listToTreeData } from '@/index/utils/list-to-treedata'
let systemSettings = {
  state: {
    teamList: [], // 团队
    groupList: [], // 业务组
    projectList: [], // 技改项目
    memberList: [], // tapd所有成员
    projectRules: [], // 项目映射列表
    tapdProjectList: [], // tapd所有项目
    permisionList: [], // 权限 字段->id 列表
    roleGroupList: []// 角色组列表
  },

  getters: {
    // 上级目录, 转成树形结构
    parentTeam: state => {
      let temp = JSON.parse(JSON.stringify(state.teamList)).sort((a,b)=>{
        return a.createTime - b.createTime
      })
      temp = temp.filter(item => {
        return item.teamType === 1 // 先筛选出目录
      })
      temp = listToTreeData(temp, 0, 'parentTeamId')
      // 增加一个根目录
      temp.unshift({
        id: 0,
        parentTeamId: null,
        teamNo: 0,
        teamName: '根目录',
        teamStatus: 0,
        teamType: 1,
      })
      return temp
    },
    // 团队级联筛选列表转树型
    teamTree: state => {
      let temp = JSON.parse(JSON.stringify(state.teamList)).sort((a,b)=>{
        return a.createTime - b.createTime
      })
      temp = listToTreeData(temp,0,'parentTeamId')
      return temp
    },
    // 团队列表映射,1. 增加负责人姓名 2.增加loading
    teamListMap: state => {
      return state.teamList.map(item => {
        if (item.teamLeader) {
          let id = parseInt(item.teamLeader)
          let teamLeader = state.memberList.find(i => (i.uid === id))
          let teamLeaderName = teamLeader?.name || ''
          return { ...item, teamLeaderName, loading: false }
        }else{
          return {...item, loading: false}
        }
      })
    },
    // 业务组列表映射, 1. 增加负责人姓名 2.增加loading
    groupListMap: state => {
      return state.groupList.map(item => {
        let id = parseInt(item.groupLeader)
        let groupLeader = state.memberList.find(i => i.uid === id)
        let groupLeaderName = groupLeader?.name || ''
        return { ...item, groupLeaderName, loading: false }
      })
    },

    // tapd 未映射列表
    tapdProjectUnmapped: state => {
      let list = state.projectRules.map(item => item.tapdProjectId)
      let temp = state.tapdProjectList.filter(item => {
        return list.indexOf(item.id) === -1
      })
      return temp
    },
  },

  mutations: {
    // 1.1 存储团队列表
    saveTeamList(state, value) {
      state.teamList = value.sort((a,b)=>{
        return b.createTime - a.createTime
      })
    },

    // 2.1 存储业务组列表
    saveGroupList(state, value) {
      state.groupList = value.sort((a,b)=>{
        return b.createTime - a.createTime
      })
    },
    // 2.2 更新技改项目状态
    changeGroupStatus(state, id) {
      let node = state.groupList.find(item => item.id === id)
      node.groupStatus = node.groupStatus === 1 ? 0 : 1
    },

    // 3.1 存储技改项目列表
    saveProjectList(state, value) {
      state.projectList = value.sort((a,b)=>{
        return b.createTime - a.createTime
      })
    },
    // 3.2 更新技改项目状态
    changeProjectStatus(state, id) {
      let node = state.projectList.find(item => item.id === id)
      node.projectStatus = node.projectStatus === 1 ? 0 : 1
    },

    // 4.1 存储TAPD用户列表
    saveMemberList(state, value) {
      state.memberList = value
    },
    // 4.2 存储Tapd所有项目
    saveTapdProjectList(state, data) {
      state.tapdProjectList = data
    },

    // 5.1 存储项目映射列表
    saveProjectAllRules(state, value) {
      state.projectRules = value
    },
    // 5.2 本地删除项目映射
    deleteProjectRule(state, id) {
      let index = state.projectRules.findIndex(item => item.id === id)
      state.projectRules.splice(index, 1)
    },
    // 5.3 本地更新项目映射
    updataProjectRules(state, data){
      // eslint-disable-next-line no-unused-vars
      let node = state.projectRules.find(item => {
        return item.id === data.id
      })
      node = Object.assign(node,data)
    },
    
    // 6.1 存储权限 字段->id 列表
    savePermisionList(state, data){
      state.permisionList = data
    },
    // 6.2 存储角色组列表(tapd项目列表)
    saveRoleGroupList(state, data){
      state.roleGroupList = data
    }
  },

  actions: {
    // 1. 获取团队列表
    async getTeamList({ commit }) {
      let { data } = await getTeamList()
      if(data){
        commit('saveTeamList', data)
      }
    },
    // 2. 获取业务组列表
    async getGroupList({ commit }) {
      let {data} = await getGroupList()
      if(data){
        commit('saveGroupList', data)
      }
    },
    // 3. 获取技改项目列表
    async getProjectList({ commit }) {
      let {data} = await getProjectList()
      if(data){
        commit('saveProjectList', data)
      }
    },
    // 4.1 获取Tapd用户列表
    async getMemberList({ commit }) {
      let {data} = await getMemberList()
      if(data){
        commit('saveMemberList', data)
      }
    },
    // 4.2 获取Tapd所有项目
    async getTapdProject({ commit }) {
      let {data} = await getTapdProject()
      if(data){
        commit('saveTapdProjectList', data)
      }
    },

    // 5. 获取项目映射列表
    async getProjectAllRules({ commit }) {
      let {data} = await getProjectAllRules()
      if(data){
        commit('saveProjectAllRules', data)
      }
    },

    // 6.1 获取权限 字段->id 列表
    async getPermisionList({ commit }) {
      let {data} = await getPermisionList()
      if(data) {
        commit('savePermisionList', data)
      }
    },
    // 6.2 获取角色组列表(tapd项目列表)
    async getRoleGroupList({ commit }, params) {
      let {data} = await getRoleGroupList(params)
      if(data) {
        let unSetting = data.filter(item => item.choose===0)
        commit('saveRoleGroupList', unSetting)
      }
    },
  },
}
export default systemSettings
