import { getTeamList, getTeamSelQuaList } from '@/index/api'
import { listToTreeData } from '@/index/utils/list-to-treedata'
let teamResource = {
  state: {
    teamList: [], // 团队列表
    teamResourceList: [], // 团队资源, 只显示一个季度
  },

  getters: {
    // 1. 团队列表, 先过滤掉没有叶子节点的目录, 再转树形
    teamTree: state => {
      let temp = JSON.parse(JSON.stringify(state.teamList))
      // 目录节点
      let directory = temp.filter(item => (item.teamType===1))
      // 叶子节点
      let leaf = temp.filter(item => (item.teamType===0))
      let leafPidList  = leaf.map(item => (item.parentTeamId))
      // 有child的目录节点
      let haveChild = directory.filter((item) => {
        return leafPidList.find(i => {
          return i === item.id
        })
      })
      temp = [...haveChild, ...leaf]
      temp = listToTreeData(temp,0,'parentTeamId')
      return temp
    },
    // 2. 团队资源列表, 添加没有更新记录的团队, 充当第一次更新入口
    teamResource: state => {
      // 已有更新记录的团队id
      let TeamId = state.teamResourceList.map(item => {
        return item.teamId
      })
      // 没有更新记录的叶子节点
      let temp = state.teamList.filter(item => {
        return item.teamType === 0 && TeamId.indexOf(item.id)===-1
      })
      let res = JSON.parse(JSON.stringify(state.teamResourceList))
      temp.forEach(item => {
        res.push(
          {
            teamId: item.id,
            teamName: item.teamName,
            quarterStartTime: null,
            createTime: null,
            inMember: 0,
            outMember: 0,
            member: 0,
            inResource: 0,
            outResource: 0,
            resource: 0,
          },
        )
      })
      return res
    }
  },

  mutations: {
    // 1. 存储团队列表
    saveTeamList(state, value) {
      state.teamList = value
    },
    // 2. 存储团队资源列表
    saveTeamResourceList(state, value){
      state.teamResourceList = value.sort((a,b)=>{
        return b.createTime - a.createTime
      })
    }
  },

  actions: {
    // 1. 获取团队列表,这里只要已启用的
    async getTeamList({ commit }) {
      let { data } = await getTeamList({teamStatus:0})
      data && commit('saveTeamList', data)
    },

    // 2. 获取团队资源列表 (按季度展示)
    async getTeamSelQuaList({ commit }, params) {
      let {data} = await getTeamSelQuaList(params)
      data && commit('saveTeamResourceList', data)
    },
  },
}
export default teamResource
