import { mockRoutesResource } from "@/index/mock/mockRoutesResource";
import { getToken, getUserInfo } from "@/index/api"
function handleRoutesResource(
  mockRoutesResource = [],
  parent
) {
  for (let item of mockRoutesResource) {
    item.parent = parent;
    if (item.children) {
      handleRoutesResource(item.children, item);
    }
  }
}

let user = {
  state: {
    token: "",
    userName: "",
    avatar: "",
    menu: [],
    button: [],
    routesResource:  [],
    isAdmin: false,
    loginFailed: false, // 非白名单导致的登录失败
  },

  getters: {
    buttonCodeList: state => {
      if(state.button.length>0){
        return state.button.map(item => item.code)
      }else {
        return []
      }
    },
    menuCodeList: state => {
      if(state.menu.length>0){
        return state.menu.map(item => item.code)
      } else {
        return []
      }
      
    }
  },
  mutations: {
    saveRoutesResource(state, value) {
      state.routesResource = value;
    },
    // 修改 token
    changeToken(state, value) {
      state.token = value;
    },
    // 修改用户名
    changeUserName(state, value){
      state.userName = value
    },
    // 修改管理员
    changeAdmin(state, value){
      state.isAdmin = value
    },
    // 用户菜单
    changeMenu(state, value) {
      state.menu = value
    },
    // 用户按钮
    changeButton(state, value) {
      state.button = value
    },
    // 登录失败
    changeLoginFailed(state, value){
      state.loginFailed = value
    }
  },

  actions: {
    // 获取用户路由
    async getRoutesResource({commit, rootGetters, rootState }) {
      // 判断后端是否返回"需求资源确认记录"菜单
      if(rootState.user.isAdmin === false
        && rootGetters['user/menuCodeList'].indexOf('story_resource_record')===-1
      ){
        mockRoutesResource[2].children.splice(1, 1)
      }
      return new Promise(resolve => {
        setTimeout(() => {
          handleRoutesResource(mockRoutesResource);
          commit("saveRoutesResource", mockRoutesResource);
          resolve(mockRoutesResource);
        }, 0);
      });
    },
    // 获取token
    async getToken({ commit }, params) {
      const { data } = await getToken(params);
      if (data) {
        commit("changeToken", data);
        return data;
      } else {
        // errcode 0, data为null, 说明是没有登录权限, 要么加入管理员, 要么加入登录白名单
        commit("changeLoginFailed", true)
      }
    },
    // 获取用户信息
    async getUserInfo({ commit }) {
      const {data} = await getUserInfo()
      if(data){
        const {name, admin, resourceMap: {button, menu}} = data
        commit('changeUserName', name)
        commit('changeAdmin', admin)
        // 后台button和menu有可能不返回
        if(button){
          commit('changeButton', button)
        }
        if(menu){
          commit('changeMenu', menu)
        }
      }
    }
  }
};

export default user;
