import constants from "./constants"
const { nullValueArr } = constants;

export default {
  /**
   * 减法运算，避免数据相减小数点后产生多位数和计算精度损失。
   *
   * @param num1 被减数 | num2 减数
   */
  numSub: function(num1, num2) {
    if(nullValueArr.includes(num1)||nullValueArr.includes(num2)){
      return "--";
    }
    let baseNum, baseNum1, baseNum2;
    let precision; // 精度
    try {
      baseNum1 = num1.toString().split(".")[1].length;
    } catch (e) {
      baseNum1 = 0;
    }
    try {
      baseNum2 = num2.toString().split(".")[1].length;
    } catch (e) {
      baseNum2 = 0;
    }
    baseNum = Math.pow(10, Math.max(baseNum1, baseNum2));
    precision = baseNum1 >= baseNum2 ? baseNum1 : baseNum2;
    const result = (num1 * baseNum - num2 * baseNum) / baseNum;
    return parseFloat(result.toFixed(precision));
  },
  /**
   * 加法运算，避免数据相加小数点后产生多位数和计算精度损失。
   *
   * @param num1 加数1 | num2 加数2
   */
  numAdd: function(num1, num2) {
    if(nullValueArr.includes(num1)||nullValueArr.includes(num2)){
      return "--";
    }
    let baseNum, baseNum1, baseNum2;
    let precision; // 精度
    try {
      baseNum1 = num1.toString().split(".")[1].length;
    } catch (e) {
      baseNum1 = 0;
    }
    try {
      baseNum2 = num2.toString().split(".")[1].length;
    } catch (e) {
      baseNum2 = 0;
    }
    baseNum = Math.pow(10, Math.max(baseNum1, baseNum2));
    precision = baseNum1 >= baseNum2 ? baseNum1 : baseNum2;
    const result = ((num1 * baseNum + num2 * baseNum) / baseNum);
    return parseFloat(result.toFixed(precision));
  },

  /**
   * 乘法运算，避免数据相乘小数点后产生多位数和计算精度损失。
   *
   * @param num1被乘数 | num2乘数
   */
  numMulti: function(num1, num2) {
    if(nullValueArr.includes(num1)||nullValueArr.includes(num2)){
      return "--";
    }
    let baseNum = 0;
    try {
      baseNum += num1.toString().split(".")[1].length;
    } catch (e) {
      console.log(e)
    }
    try {
      baseNum += num2.toString().split(".")[1].length;
    } catch (e) {
      console.log(e)
    }
    const result = (Number(num1.toString().replace(".", "")) * Number(num2.toString().replace(".", ""))) / Math.pow(10, baseNum);
    return result;
  },

  /**
   * 除法运算，避免数据相除小数点后产生多位数和计算精度损失。
   *
   * @param num1被除数 | num2除数
   */
  numDiv: function(num1, num2) {
    if(nullValueArr.includes(num1)||nullValueArr.includes(num2)){
      return "--";
    }
    let baseNum1 = 0;
    let baseNum2 = 0;
    let baseNum3, baseNum4;
    try {
      baseNum1 = num1.toString().split(".")[1].length;
    } catch (e) {
      baseNum1 = 0;
    }
    try {
      baseNum2 = num2.toString().split(".")[1].length;
    } catch (e) {
      baseNum2 = 0;
    }
    baseNum3 = Number(num1.toString().replace(".", ""));
    baseNum4 = Number(num2.toString().replace(".", ""));
    var x = baseNum3 / baseNum4;
    var y = Math.pow(10, baseNum2 - baseNum1);
    const result = this.numMulti(x, y);
    return result;
  },
};
