import { defaultRender, outsourcingCostRender, quarterRender, dateRender, timeRender, scheduleRender, enlargedScaleRenderFun, enlargedScaleOnlySumRenderFun, serialNumberRender, enlargedRenderFun,  } from "@/index/utils/customRender";

const LongWordsWidth = 350;
// const storyNameWidth = 130;
const priorityWidth = 75;
const dateWidth = 120;
const evaluationStatusWidth = 110;
const sizeWidth = 80;
const groupNameWidth = 130;
const approvalStatusWidth = 120;
const operationWidth = 110;

// const subStoryNameWidth = 250;
const creatorWidth = 90;
const teamNameWidth = 130;
const projectNameWidth = 130;
const scheduleWidth = 200;
const scaleWidth = 200;

const serialNumberWidth = 80;
const descriptionWidth = 90;
// const demandWidth = 130;
const dataSourceWidth = 130;
const projectNumWidth = 120;
const outsourcingCostWidth = 100;

const outsourcingUnitPriceWidth = 120;

const taskNameWidth = 140;
const quarterPlanWidth = 110;
const quantityRequiredWidth = 130;
const dateTimeWidth = 200;


//需求列表
export function genStoryListColumns(){
  return [
    {
      title: "业务需求名称",
      dataIndex: "storyName",
      // width: storyNameWidth,
      width: LongWordsWidth,
      ellipsis: true,
      key: "name",
      align: "center",
      scopedSlots: { customRender: "name" },
    },
    {
      title: "优先级",
      dataIndex: "priority",
      width: priorityWidth,
      key: "priority",
      align: "center",
      scopedSlots: { customRender: "priority" },
    },
    {
      title: "需求提交日期",
      dataIndex: "created",
      width: dateWidth,
      key: "submitDate",
      align: "center",
      customRender: dateRender,
    },
    {
      title: "计划上线日期",
      dataIndex: "planOnlineTime",
      key: "onlineDate",
      width: dateWidth,
      align: "center",
      customRender: dateRender,
    },
    {
      title: "评估状态",
      dataIndex: "evaluationStatus",
      width: evaluationStatusWidth,
      key: "evaluationStatus",
      align: "center",
      scopedSlots: { customRender: "evaluationStatus" },
    },
    {
      title: "规模",
      dataIndex: "size",
      key: "scale",
      width: sizeWidth,
      align: "center",
      customRender: enlargedScaleOnlySumRenderFun(1),
    },
    {
      title: "业务工作组",
      dataIndex: "groupName",
      width: groupNameWidth,
      ellipsis: true,
      key: "businessWorkGroup",
      align: "center",
      customRender: defaultRender,
    },
    {
      title: "审批状态",
      dataIndex: "approvalStatus",
      key: "approvalStatus",
      width: approvalStatusWidth,
      align: "center",
      scopedSlots: { customRender: "approvalStatus" },
    },
    {
      title: "操作",
      dataIndex: "operation",
      width: operationWidth,
      key: "operation",
      align: "center",
      scopedSlots: { customRender: "operation" },
    },
  ]
}

//展开的技改项目表格
export function genTechniqueDemandColumns(){
  return [
    {
      title: "技术需求名称",
      dataIndex: "storyName",
      key: "techniqueRequirementName",
      width: LongWordsWidth,
      ellipsis: true,
      align: "center",
      customRender: defaultRender,
    },
    {
      title: "提交人",
      dataIndex: "creator",
      key: "submitter",
      width: creatorWidth,
      align: "center",
      customRender: defaultRender,
    },
    {
      title: "交付团队",
      dataIndex: "teamName",
      width: teamNameWidth,
      ellipsis: true,
      key: "deliveryTeam",
      align: "center",
      customRender: defaultRender,
    },
    {
      title: "所属技改项目",
      dataIndex: "projectName",
      width: projectNameWidth,
      ellipsis: true,
      key: "belongProject",
      align: "center",
      customRender: defaultRender,
    },
    {
      title: "排期",
      dataIndex: "schedule",
      width: scheduleWidth,
      key: "schedule",
      align: "center",
      customRender: scheduleRender,
    },
    {
      title: "规模（内/外）",
      dataIndex: "scale",
      width: scaleWidth,
      key: "scale",
      align: "center",
      customRender: enlargedScaleRenderFun(1),
    },
    {
      title: "操作",
      dataIndex: "operation",
      width: operationWidth,
      key: "operation",
      align: "center",
      scopedSlots: { customRender: "operation" },
    },
  ]
}

//团队资源
export function genTeamResourceColumns(enlargedScale) {
  return [
    {
      title: "季度计划",
      dataIndex: "quarterStartTime",
      align: "center",
      customRender: quarterRender,
    },
    {
      title: "可用资源",
      dataIndex: "resource",
      align: "center",
      customRender: defaultRender,
    },
    {
      title: "剩余资源",
      dataIndex: "rest",
      align: "center",
      customRender: defaultRender,
    },
    {
      title: "本次确认需求规模",
      dataIndex: "scale",
      align: "center",
      customRender: enlargedScaleRenderFun(enlargedScale),
    },
    {
      title: "扣减本需求后剩余",
      dataIndex: "restAfterReduce",
      scopedSlots: { customRender: "confirmedRemainResource" },
      align: "center",
    },
    {
      title: "资源使用率",
      dataIndex: "percent",
      scopedSlots: { customRender: "resourceRatio" },
      align: "center",
    },
  ];
}

//任务单需求表格
export function genDemandDetailColumns(enlargedScale) {
  return [
    {
      title: "序号",
      dataIndex: "serialNumber",
      key: "serialNumber",
      width: serialNumberWidth,
      align: "center",
      customRender: serialNumberRender,
    },
    {
      title: "业务需求",
      dataIndex: "storyName",
      // width: storyNameWidth,
      width: LongWordsWidth,
      ellipsis: true,
      key: "businessRequirement",
      align: "center",
      customRender: defaultRender,
    },
    {
      title: "需求描述",
      dataIndex: "description",
      width: descriptionWidth,
      key: "requirementDescription",
      align: "center",
      scopedSlots: { customRender: "description" },
    },
    {
      title: "验收要求",
      dataIndex: "demand",
      key: "acceptanceDemand",
      // width: demandWidth,
      width: LongWordsWidth,
      ellipsis: true,
      align: "center",
      customRender: defaultRender,
    },
    {
      title: "需求来源",
      dataIndex: "dataSource",
      width: dataSourceWidth,
      key: "requirementSource",
      scopedSlots: { customRender: "requirementSource" },
      align: "center",
    },
    {
      title: "提交日期",
      dataIndex: "created",
      key: "submitDate",
      width: dateWidth,
      align: "center",
      customRender: dateRender,
    },
    {
      title: "计划上线日期",
      dataIndex: "planOnlineTime",
      width: dateWidth,
      key: "planUptime",
      align: "center",
      customRender: dateRender,
    },
    {
      title: "技改项目数量",
      dataIndex: "projectNum",
      width: projectNumWidth,
      key: "projectNum",
      align: "center",
      customRender: defaultRender,
    },
    {
      title: "规模（内/外）",
      dataIndex: "scale",
      width: scaleWidth,
      key: "scale",
      align: "center",
      customRender: enlargedScaleRenderFun(enlargedScale),
    },
    {
      title: "外包费用",
      dataIndex: "outsourcingCost",
      key: "outsourceExpense",
      width: outsourcingCostWidth,
      align: "center",
      customRender: enlargedRenderFun(enlargedScale),
    },
  ];
}

//任务单展开的技改项目表格
export function genTechnicalProjectColumns(enlargedScale) {
  return [
    { 
      title: "所属技改项目名称", 
      dataIndex: "projectName", 
      key: "techniqueProjectName", 
      // width: storyNameWidth,
      width: LongWordsWidth,
      ellipsis: true,
      align: "center", 
      customRender: defaultRender 
    },
    {
      title: "规模-内部",
      dataIndex: "inSize",
      width: sizeWidth,
      key: "interiorScale",
      align: "center",
      customRender: enlargedRenderFun(enlargedScale),
    },
    {
      title: "规模-外包",
      dataIndex: "outSize",
      width: sizeWidth,
      key: "exteriorScale",
      align: "center",
      customRender: enlargedRenderFun(enlargedScale),
    },
    { 
      title: "外包人力单价", 
      dataIndex: "outsourcingUnitPrice", 
      key: "outsourcePrice", 
      width: outsourcingUnitPriceWidth,
      align: "center", 
      customRender: defaultRender 
    },
    {
      title: "外包费用",
      dataIndex: "outsourcingCost",
      width: outsourcingCostWidth,
      key: "outsourceExpense",
      align: "center",
      customRender: enlargedRenderFun(enlargedScale),
    },
  ];
}

//需求确认记录列表
export function genConfirmRecordListColumns(){
  return [
    {
      title: "任务名称",
      dataIndex: "taskName",
      width: taskNameWidth,
      ellipsis: true,
      align: "center",
      customRender: defaultRender,
    },
    {
      title: "季度计划",
      dataIndex: "quarterStartTime",
      align: "center",
      width: quarterPlanWidth,
      customRender: quarterRender,
    },
    {
      title: "业务工作组",
      dataIndex: "groupName",
      width: groupNameWidth,
      ellipsis: true,
      align: "center",
      customRender: defaultRender,
    },
    {
      title: "纳入需求数量",
      dataIndex: "total",
      width: quantityRequiredWidth,
      align: "center",
      customRender: defaultRender,
      // customRender: (text, row, index) => {
      //   return row.rmStoryResources.length;
      // },
    },
    {
      title: "本季度完成需求",
      dataIndex: "complete",
      width: quantityRequiredWidth,
      align: "center",
      customRender: defaultRender,
    },
    {
      title: "待后续上线需求",
      dataIndex: "unComplete",
      width: quantityRequiredWidth,
      align: "center",
      customRender: defaultRender,
    },
    {
      title: "任务单确认时间",
      dataIndex: "approvalTime",
      width: dateTimeWidth,
      align: "center",
      customRender: timeRender,
    },
    { 
      title: "操作", 
      key: "operation", 
      scopedSlots: { customRender: "operation" }, 
      width: operationWidth,
      align: "center" 
    },
  ]
}

//确认记录展开的业务需求表格
export function genBusinessRequirementsColumns (){
  return [
    {
      title: "业务需求",
      dataIndex: "storyName",
      // width: storyNameWidth,
      width: LongWordsWidth,
      ellipsis: true,
      align: "center",
      customRender: defaultRender,
    },
    {
      title: "需求来源",
      dataIndex: "dataSource",
      // width: dataSourceWidth,
      scopedSlots: { customRender: "dataSource" },
      align: "center",
    },
    {
      title: "提交日期",
      dataIndex: "created",
      // width: dateWidth,
      align: "center",
      customRender: dateRender,
    },
    {
      title: "计划上线日期",
      dataIndex: "planOnlineTime",
      // width: dateWidth,
      align: "center",
      customRender: dateRender,
    },
    {
      title: "规模（内/外）",
      dataIndex: "scale",
      // width: scaleWidth,
      align: "center",
      customRender: enlargedScaleRenderFun(1),
    },
    {
      title: "外包费用",
      dataIndex: "outsourcingCost",
      // width: outsourcingCostWidth,
      align: "center",
      customRender: outsourcingCostRender,
    },
  ]
}