import axios from "axios";
import Vue from "vue";
import message from "ant-design-vue/es/message";

const axiosInstance = axios.create({
  baseURL: process.env.VUE_APP_API_BASE_URL,
  timeout: 45000,
});
let hasPrompted;
const errorHandler = (err) => {
  if (err.message.errcode) {
    // 后端返回的错误码
    // message.error(err.message.errmsg);
    err.message = err.message.errmsg
  } else {
    // http 返回的错误码
    let errMsg = "";
    if (err.code === "ECONNABORTED") {
      errMsg = "网络请求超时";
    } else {
      if (err && err.response) {
        let status = err.response.status;
        switch (status) {
          case 400:
            errMsg = "参数错误";
            break;
          case 401:
            if(!hasPrompted){
              hasPrompted = message('获取token失败，请刷新重试。');
            }
            break;
          case 404:
            errMsg = "没有找到相关资源";
            break;
          case 405:
            errMsg = "请求方法不允许";
            break;
          case 500:
            errMsg = "服务器异常";
            break;
          default:
            errMsg = "连接服务器出错" + status;
        }
      } else {
        errMsg = "连接服务器失败";
      }
    }
    // message.error(errMsg);
    err.message = errMsg
  }
  return { err };
};

axiosInstance.interceptors.request.use(
  (config) => {
    if (config.method === 'get') {
      config.params = config.data;
    }
    // 控制 loading 显示
    if (config.data && config.data._loading === false) {
      const { _loading, ...data } = config.data;
      config.headers._loading = _loading !== false;
      config.data = data;
      if (data.formData) {
        // form data 数据需要特殊处理
        config.data = data.formData;
      }
    }
    if (config.headers._loading !== false) {
      config.headers._loading = true;
    }

    // 头部增加 token
    if (Vue.prototype.$token) {
      config.headers.Authorization = "Bearer " + Vue.prototype.$token;
    }

    return config;
  },
  (err) => {
    return Promise.reject(err);
  }
);

axiosInstance.interceptors.response.use((response) => {
  if (!response.data) {
    return response;
  }
  if (response.data.errcode) {
    // 如果 errcode 有值并且不为0的时候抛出错误
    return errorHandler({ message: response.data });
  }
  // return { result: response.data };
  return response.data
}, errorHandler);

// export default axiosInstance;

const request = (method, url, data = {}) => {
  return axiosInstance.request({
      method,
      url,
      data
  }).then(data => data
  ).catch(err => ({
      err
  }))
}
export default request